@@ -175,15 +175,6 @@ Applet *PluginLoader::loadApplet(const QString &name, uint appletId, const QVari
 
     // Need to pass the empty directory because it's where plasmoids used to be
     auto plugin = d->plasmoidCache.findPluginById(name, PluginLoaderPrivate::s_plasmoidsPluginDir);
-#if PLASMA_BUILD_DEPRECATED_SINCE(5, 86)
-    if (!plugin.isValid()) {
-        auto plugin = d->plasmoidCache.findPluginById(name, QString());
-        if (plugin.isValid()) {
-            qCWarning(LOG_PLASMA) << "The applet" << plugin.fileName()
-                                  << "is installed in a deprecated location, install it in the plasma/applets namespace instead";
-        }
-    }
-#endif
 
     const KPackage::Package p = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/Applet"), name);
 
@@ -192,15 +183,6 @@ Applet *PluginLoader::loadApplet(const QString &name, uint appletId, const QVari
         const QString parentPlugin = p.metadata().value(QStringLiteral("X-Plasma-RootPath"));
         if (!parentPlugin.isEmpty()) {
             plugin = d->plasmoidCache.findPluginById(parentPlugin, PluginLoaderPrivate::s_plasmoidsPluginDir);
-#if PLASMA_BUILD_DEPRECATED_SINCE(5, 86)
-            if (!plugin.isValid()) {
-                auto plugin = d->plasmoidCache.findPluginById(name, QString());
-                if (plugin.isValid()) {
-                    qCWarning(LOG_PLASMA) << "The applet" << plugin.fileName()
-                                          << "is installed in a deprecated location, install it in the plasma/applets namespace instead";
-                }
-            }
-#endif
         }
     }
 
@@ -380,8 +362,7 @@ ContainmentActions *PluginLoader::loadContainmentActions(Containment *parent, co
         }
     }
 
-    // FIXME: this is only for backwards compatibility, but probably will have to stay
-    // for the time being
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 88)
     QString constraint = QStringLiteral("[X-KDE-PluginInfo-Name] == '%1'").arg(name);
     KService::List offers = KServiceTypeTrader::self()->query(QStringLiteral("Plasma/ContainmentActions"), constraint);
 
@@ -393,12 +374,17 @@ ContainmentActions *PluginLoader::loadContainmentActions(Containment *parent, co
     }
 
     KService::Ptr offer = offers.first();
+    qCWarning(LOG_PLASMA) << "Plugin" << name << "was loaded using deprecated KServiceTypeTrader."
+                          << "Use embedded json metadata and install the plugin in plasma/containmentactions namespace instead";
 
     KPluginMetaData data(offer->library());
     QVariantList allArgs;
     allArgs << offer->storageId() << args;
 
     return KPluginFactory::instantiatePlugin<Plasma::ContainmentActions>(data, nullptr, allArgs).plugin;
+#else
+    return nullptr;
+#endif
 }
 
 #if PLASMA_BUILD_DEPRECATED_SINCE(5, 83)
@@ -456,8 +442,7 @@ Package PluginLoader::loadPackage(const QString &packageFormat, const QString &s
     return Package();
 }
 #endif
-
-QList<KPluginMetaData> PluginLoader::listAppletMetaData(const QString &category, const QString &parentApp)
+QList<KPluginMetaData> listAppletMetaDataInternal(const QString &category, const QString &parentApp)
 {
     auto platforms = KDeclarative::KDeclarative::runtimePlatform();
     // For now desktop always lists everything
@@ -519,6 +504,18 @@ QList<KPluginMetaData> PluginLoader::listAppletMetaData(const QString &category,
     return KPackage::PackageLoader::self()->findPackages(QStringLiteral("Plasma/Applet"), QString(), filter);
 }
 
+QList<KPluginMetaData> PluginLoader::listAppletMetaData(const QString &category)
+{
+    return listAppletMetaDataInternal(category, QString());
+}
+
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 88)
+QList<KPluginMetaData> PluginLoader::listAppletMetaData(const QString &category, const QString &parentApp)
+{
+    return listAppletMetaDataInternal(category, parentApp);
+}
+#endif
+
 #if PLASMA_BUILD_DEPRECATED_SINCE(5, 28)
 KPluginInfo::List PluginLoader::listAppletInfo(const QString &category, const QString &parentApp)
 {
@@ -550,7 +547,7 @@ KPluginInfo::List PluginLoader::listAppletInfo(const QString &category, const QS
 QList<KPluginMetaData> PluginLoader::listAppletMetaDataForMimeType(const QString &mimeType)
 {
     auto filter = [&mimeType](const KPluginMetaData &md) -> bool {
-        return KPluginMetaData::readStringList(md.rawData(), QStringLiteral("X-Plasma-DropMimeTypes")).contains(mimeType);
+        return md.value(QStringLiteral("X-Plasma-DropMimeTypes"), QStringList()).contains(mimeType);
     };
     return KPackage::PackageLoader::self()->findPackages(QStringLiteral("Plasma/Applet"), QString(), filter);
 }
@@ -572,13 +569,13 @@ QList<KPluginMetaData> PluginLoader::listAppletMetaDataForUrl(const QUrl &url)
     auto filter = [&parentApp](const KPluginMetaData &md) -> bool {
         const QString pa = md.value(QStringLiteral("X-KDE-ParentApp"));
         return (parentApp.isEmpty() || pa == parentApp) //
-            && !KPluginMetaData::readStringList(md.rawData(), QStringLiteral("X-Plasma-DropUrlPatterns")).isEmpty();
+            && !md.value(QStringLiteral("X-Plasma-DropUrlPatterns"), QStringList()).isEmpty();
     };
     const QList<KPluginMetaData> allApplets = KPackage::PackageLoader::self()->findPackages(QStringLiteral("Plasma/Applet"), QString(), filter);
 
     QList<KPluginMetaData> filtered;
     for (const KPluginMetaData &md : allApplets) {
-        const QStringList urlPatterns = KPluginMetaData::readStringList(md.rawData(), QStringLiteral("X-Plasma-DropUrlPatterns"));
+        const QStringList urlPatterns = md.value(QStringLiteral("X-Plasma-DropUrlPatterns"), QStringList());
         for (const QString &glob : urlPatterns) {
             QRegExp rx(glob);
             rx.setPatternSyntax(QRegExp::Wildcard);
@@ -709,7 +706,7 @@ KPluginInfo::List PluginLoader::listContainmentsForMimeType(const QString &mimeT
 {
     auto filter = [&mimeType](const KPluginMetaData &md) -> bool {
         return md.serviceTypes().contains(QLatin1String("Plasma/Containment"))
-            && KPluginMetaData::readStringList(md.rawData(), QStringLiteral("X-Plasma-DropMimeTypes")).contains(mimeType);
+            && md.value(QStringLiteral("X-Plasma-DropMimeTypes"), QStringList()).contains(mimeType);
     };
 
     return KPluginInfo::fromMetaData(KPackage::PackageLoader::self()->findPackages(QStringLiteral("Plasma/Applet"), QString(), filter).toVector());
@@ -777,8 +774,6 @@ QVector<KPluginMetaData> PluginLoader::listContainmentActionsMetaData(const QStr
     }
 
 #if KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
-    // FIXME: this is only for backwards compatibility, but probably will have to stay
-    // for the time being
     QSet<QString> knownPlugins;
     for (const KPluginMetaData &p : std::as_const(plugins)) {
         knownPlugins.insert(p.pluginId());
@@ -864,6 +859,7 @@ KPluginInfo::List PluginLoader::internalContainmentActionsInfo() const
 }
 #endif
 
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 88)
 static KPluginInfo::List standardInternalInfo(const QString &type, const QString &category = QString())
 {
     QStringList files = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation,
@@ -900,6 +896,7 @@ KPluginInfo::List PluginLoader::standardInternalServiceInfo() const
 {
     return standardInternalInfo(QStringLiteral("services"));
 }
+#endif
 
 KPluginMetaData PluginLoaderPrivate::Cache::findPluginById(const QString &name, const QString &pluginNamespace)
 {
