@@ -336,6 +336,12 @@ void AppletQuickItemPrivate::preloadForExpansion()
     qCDebug(LOG_PLASMAQUICK) << "Applet" << applet->title() << "loaded after" << (QDateTime::currentMSecsSinceEpoch() - time) << "msec";
 }
 
+void AppletQuickItemPrivate::anchorsFillParent(QQuickItem *item, QQuickItem *parent)
+{
+    // just set once, don't bind
+    QQmlProperty::write(item, QStringLiteral("anchors.fill"), QVariant::fromValue<QObject *>(parent));
+}
+
 void AppletQuickItemPrivate::compactRepresentationCheck()
 {
     if (!initComplete) {
@@ -371,12 +377,7 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
             }
 
             item->setParentItem(q);
-            {
-                // set anchors
-                QQmlExpression expr(QtQml::qmlContext(qmlObject->rootObject()), item, QStringLiteral("parent"));
-                QQmlProperty prop(item, QStringLiteral("anchors.fill"));
-                prop.write(expr.evaluate());
-            }
+            anchorsFillParent(item, q);
 
             if (compactRepresentationItem) {
                 compactRepresentationItem->setVisible(false);
@@ -384,12 +385,13 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
 
             currentRepresentationItem = item;
             connectLayoutAttached(item);
+
             expanded = true;
             Q_EMIT q->expandedChanged(true);
         }
 
-        // Icon
     } else {
+        // Icon
         QQuickItem *compactItem = createCompactRepresentationItem();
         QQuickItem *compactExpanderItem = createCompactRepresentationExpanderItem();
 
@@ -398,12 +400,7 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
             compactItem->setVisible(true);
             compactExpanderItem->setParentItem(q);
             compactExpanderItem->setVisible(true);
-            {
-                // set anchors
-                QQmlExpression expr(QtQml::qmlContext(qmlObject->rootObject()), compactExpanderItem, QStringLiteral("parent"));
-                QQmlProperty prop(compactExpanderItem, QStringLiteral("anchors.fill"));
-                prop.write(expr.evaluate());
-            }
+            anchorsFillParent(compactExpanderItem, q);
 
             if (fullRepresentationItem) {
                 fullRepresentationItem->setProperty("parent", QVariant());
